package App::Bootstrap::Perl;
# git description: v0.16-6-g717c8d8

our $AUTHORITY = 'cpan:SCHWIGON';
# ABSTRACT: Bootstrap Perl inclusive CPAN from git
$App::Bootstrap::Perl::VERSION = '0.17';
use 5.006;
use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::Bootstrap::Perl - Bootstrap Perl inclusive CPAN from git

=head1 ABOUT

L<bootstrap-perl|bootstrap-perl> can compile and setup a complete Perl
environment from git, inclusive initial CPAN setup with distroprefs to
ensure completely unattended installation.

=head1 AUTHOR

Steffen Schwigon <ss5@renormalist.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by Steffen Schwigon.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
